<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:hiko="http://www.historischekommission-muenchen.de" xmlns:my="http://zeromat.org" version="2.0">

    <xsl:import href="../minrprot_ansicht_pdf.xsl"/>

    <!-- - - - - - - - - - -    SCHRIFTGRÖẞEN   - - - - - - - - - - -->
    <xsl:variable name="ftsz_Fließtext" select="'11pt'"/>
    <xsl:variable name="ftsz_Protokollkopf" select="'13pt'"/>
    <xsl:variable name="ftsz_Überschrift_Abschnitt" select="'13pt'"/>

    <xsl:variable name="ftsz_Kopfzeile" select="'10pt'"/>
    <xsl:variable name="ftsz_Seitenzahl" select="'11pt'"/>

    <xsl:variable name="ftsz_Fußnoten" select="'9pt'"/>
    <xsl:variable name="ftsz_Fußnziffer_Text" select="'8pt'"/>
    <xsl:variable name="ftsz_Fußnziffer_Apparat" select="'6pt'"/>

    <xsl:variable name="ftsz_Erläuterungstext" select="'9pt'"/>
    <xsl:variable name="ftsz_PTVZTO" select="'9pt'"/>

    <xsl:variable name="ftsz_UGQ" select="'10pt'"/>
    <xsl:variable name="ftsz_GQL" select="'10pt'"/>
    <xsl:variable name="ftsz_PER" select="'9pt'"/>
    <xsl:variable name="ftsz_SSW" select="'9pt'"/>

    <xsl:variable name="fnpadding_sm" select="'0.05em'"/>
    <xsl:variable name="fnpadding_md" select="'0.15em'"/>
    <xsl:variable name="fnpadding_lg" select="'0.32em'"/>


    <!-- - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
                                ABSCHNITTE & PROTOKOLLE
        - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -->

    <!-- - - - - - - - - - -    PROTOKOLLZUSAMMENFASSUNG    - - - - - - - - - - -->
    <xsl:template match="tei:div[@type = 'Protokollzusammenfassung']">

        <xsl:variable name="protID">
            <xsl:value-of select="@corresp"/>
        </xsl:variable>

        <fo:table width="117mm" space-after="8mm" border-separation="0" border-collapse="collapse" font-size="{$ftsz_Fließtext}">
            <fo:table-body>
                <fo:table-row margin-bottom="0.5em" page-break-after="avoid">
                    <fo:table-cell width="14mm">
                        <xsl:apply-templates select="./tei:head/tei:num" mode="ptvz"/>
                    </fo:table-cell>
                    <fo:table-cell width="20mm" text-align="right" padding-right="4mm">
                        <xsl:apply-templates select="./tei:head/tei:date" mode="ptvz"/>
                    </fo:table-cell>
                    <fo:table-cell width="73mm">
                        <xsl:apply-templates select="./tei:head/tei:title" mode="ptvz"/>
                    </fo:table-cell>
                    <fo:table-cell width="10mm">
                        <fo:block>S.&#xA0;<fo:page-number-citation ref-id="{$protID}"/></fo:block>
                    </fo:table-cell>
                </fo:table-row>
                <fo:table-row>
                    <fo:table-cell>
                        <fo:block/>
                    </fo:table-cell>
                    <fo:table-cell>
                        <fo:block/>
                    </fo:table-cell>
                    <fo:table-cell font-size="{$ftsz_PTVZTO}">
                        <xsl:apply-templates select=".//tei:p" mode="ptvz"/>
                    </fo:table-cell>
                    <fo:table-cell>
                        <fo:block/>
                    </fo:table-cell>
                </fo:table-row>
            </fo:table-body>
        </fo:table>
    </xsl:template>


    <!-- - - - - - - - - - -    ABVZ    - - - - - - - - - - -->
    <xsl:template match="tei:table[ancestor::tei:body[@xml:id = 'body_ehr33aABVZ']]">
        <fo:table width="117mm" border-separation="0" border-collapse="collapse" font-size="{$ftsz_Fließtext}" line-height="1">
            <fo:table-column column-width="27mm" text-align="left"/>
            <fo:table-column column-width="90mm" text-align="left"/>

            <fo:table-body>
                <xsl:apply-templates select="./tei:row" mode="abvz"/>
            </fo:table-body>
        </fo:table>
    </xsl:template>

    <xsl:template match="tei:row" mode="abvz">
        <fo:table-row>
            <fo:table-cell width="27mm" text-align="left" line-height="115%">
                <xsl:apply-templates select="tei:cell[@role = 'abbr']" mode="abvz"/>
            </fo:table-cell>
            <fo:table-cell width="90mm" text-align="left" line-height="115%">
                <xsl:apply-templates select="tei:cell[@role = 'expan']" mode="abvz"/>
            </fo:table-cell>
        </fo:table-row>
    </xsl:template>

    <xsl:template match="tei:cell" mode="abvz">
        <fo:block>
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>


    <!-- - - - - - - - - - -    FUßNOTE - - - - - - - - - - -->
    <xsl:template match="tei:note">
        <xsl:variable name="currentBodyId">
            <xsl:value-of select="ancestor::tei:body/@xml:id"/>
        </xsl:variable>

        <xsl:choose>
            <xsl:when test="@type"/>

            <xsl:otherwise>
                <xsl:variable name="footnoteNumber">
                    <xsl:choose>
                        <xsl:when test="@n">
                            <xsl:value-of select="@n"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <!--Fußnotennummer generieren indem die Zahl der vorherigen <note>-Elemente im selben Dokument gezählt werden
                                (nur <note>-Elemente ohne @type sind echte Fußnoten -->
                            <xsl:value-of select="count(preceding::tei:note[not(@type) and ancestor::tei:body[@xml:id = $currentBodyId]]) + 1"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>

                <!-- TODO: Seitenumbruchsattribute überschreiben nicht Seitenumbruchssperre von Top-Überschriften und sorgen dadurch für Satzprobleme-->
                <fo:footnote page-break-inside="auto" page-break-after="auto">
                    <xsl:variable name="footnotePadding" select="hiko:getFootnotePadding(.)"/>

                    <fo:inline font-size="{$ftsz_Fußnziffer_Text}" baseline-shift="17%" font-family="{$ftSf}" padding-left="{$footnotePadding}">
                        <xsl:value-of select="$footnoteNumber"/>
                    </fo:inline>
                    <fo:footnote-body font-size="{$ftsz_Fußnoten}" font-family="{$ftSf}" color="black" text-indent="0" line-height="110%" text-align="justify" page-break-inside="auto" page-break-after="auto" overflow="error-if-overflow">
                        <fo:list-block provisional-distance-between-starts="4mm">
                            <fo:list-item>
                                <fo:list-item-label end-indent="label-end()">
                                    <fo:block font-size="{$ftsz_Fußnziffer_Apparat}" baseline-shift="super" line-height="110%">
                                        <xsl:value-of select="$footnoteNumber"/>
                                    </fo:block>
                                </fo:list-item-label>
                                <fo:list-item-body start-indent="body-start()" page-break-inside="auto" page-break-after="auto" overflow="error-if-overflow">
                                    <fo:block page-break-inside="auto" page-break-after="auto">
                                        <xsl:apply-templates/>
                                    </fo:block>
                                </fo:list-item-body>
                            </fo:list-item>
                        </fo:list-block>
                    </fo:footnote-body>
                </fo:footnote>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>


    <!-- - - - - - - - - - -    PROTOKOLLKOPF  - - - - - - - - - - -->
    <xsl:template match="tei:div[@type = 'Dokumentenkopf']">
        <xsl:variable name="bodyID">
            <xsl:value-of select="ancestor::tei:body/@xml:id"/>
        </xsl:variable>
        <xsl:variable name="protID" select="substring-after($bodyID, '_')"/>
        <fo:block>
            <!--Protokollnummer-->
            <fo:block font-family="{$ftSfBd}" font-size="{$ftsz_Protokollkopf}" text-align="center" id="{$protID}" space-after="2mm">
                <fo:marker marker-class-name="protokollnummer"> Nr. <xsl:apply-templates select="tei:head/tei:num"/>
                </fo:marker>
                <xsl:apply-templates select="tei:head/tei:num"/>
            </fo:block>

            <fo:table table-layout="fixed" width="117mm" border-collapse="separate" border-spacing="0mm 6mm" space-after="1mm">
                <fo:table-column column-width="47mm"/>
                <fo:table-column column-width="5mm"/>
                <fo:table-column column-width="65mm"/>


                <fo:table-body>
                    <!--Protokolltitel & Datum -->
                    <fo:table-row>
                        <fo:table-cell display-align="after">
                            <fo:block font-family="{$ftSfBd}" font-size="{$ftsz_Protokollkopf}" hyphenate="false">
                                <xsl:apply-templates select="tei:head/tei:seg"/>
                            </fo:block>
                        </fo:table-cell>
                        <fo:table-cell>
                            <fo:block/>
                        </fo:table-cell>
                        <fo:table-cell text-align="right" display-align="after">
                            <fo:block font-family="{$ftSfBd}" font-size="{$ftsz_Protokollkopf}" hyphenate="false">
                                <fo:marker marker-class-name="protokolldatum">
                                    <xsl:value-of select="my:replMonth(format-date(.//tei:head[1]//tei:date[1]/@when, '[D1]. [MNn] [Y0001]'))"/>
                                </fo:marker>
                                <xsl:apply-templates select="tei:head/tei:date" mode="ohnezeit"/>
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>

                    <!--Beginn- & Endzeitpunkt-->
                    <fo:table-row>
                        <fo:table-cell>
                            <fo:block>Beginn: <xsl:value-of select="tei:head//tei:time[@type = 'Beginn']"/>
                            </fo:block>
                        </fo:table-cell>

                        <fo:table-cell>
                            <fo:block/>
                        </fo:table-cell>

                        <fo:table-cell text-align="right">
                            <fo:block>Ende: <xsl:value-of select="tei:head//tei:time[@type = 'Ende']"/>
                            </fo:block>
                        </fo:table-cell>
                    </fo:table-row>

                </fo:table-body>
            </fo:table>
        </fo:block>

        <xsl:apply-templates select="tei:div"/>
    </xsl:template>


    <!-- - - - - - - - - - -    BIOGRAMMPLATZHALTER - - - - - - - - - - -->
    <xsl:template match="tei:ref[@type = 'Biogramm_Platzhalter']">
        <xsl:variable name="placeholderID">
            <xsl:value-of select="./@target"/>
        </xsl:variable>
        <xsl:variable name="placeholderValue">
            <xsl:value-of select="//tei:body[@xml:id = 'body_PER']//tei:person[@xml:id = $placeholderID]/tei:note[@type = 'Biogramm']"/>
        </xsl:variable>

        <!--Falls Biogramm noch nicht ausgefüllt ist bleibt der Biogrammplatzhalter stehen-->
        <fo:inline id="{generate-id()}">
            <xsl:choose>
                <xsl:when test="$placeholderValue != ''">
                    <xsl:apply-templates select="//tei:body[@xml:id = 'body_PER']//tei:person[@xml:id = $placeholderID]/tei:note[@type = 'Biogramm']" mode="rdb"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates/>
                </xsl:otherwise>
            </xsl:choose>
        </fo:inline>
    </xsl:template>

    <!-- Wenn Biogramm bereits in Fußnote integriert war, ID für Register erzeugen (bei integrierter Gesamtdatei) -->
    <xsl:template match="tei:note[@type = 'Biogramm']">
        <fo:inline id="{generate-id()}"/>
        <xsl:apply-templates/>
    </xsl:template>

    <!-- Wenn Biogramm aus RDB eingefügt wird kein ID für Register erzeugen (bei nicht integrierter Gesamtdatei  -->
    <xsl:template match="tei:note[@type = 'Biogramm']" mode="rdb">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="//tei:note[@type = 'Biogramm']/tei:name[@type = 'Hervorhebung']">
        <fo:inline font-family="{$ftSfObl}">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>


    <!-- - - - - - - - - - -    TEXTELEMENTE    - - - - - - - - - - -->
    <xsl:template match="tei:rs[@type = 'Person']">
        <fo:inline id="{generate-id()}">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:rs[@type = 'Unterzeichner']">
        <fo:inline id="{generate-id()}">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:rs[@type = 'Sachschlagwort']">
        <fo:inline id="{generate-id()}">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:rs[@type = 'Ort']">
        <fo:inline id="{generate-id()}">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:rs[@type = 'Ungedruckt']">
        <fo:inline>
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <!--Sachschlagwort-Hinterlegungs-Elemente entfernen-->
    <xsl:template match="tei:index[@indexName = 'Sachschlagwörter']">
        <xsl:choose>
            <xsl:when test="ancestor::tei:*[local-name() = 'p' or local-name() = 'note' or local-name() = 'table']">
                <fo:inline id="{generate-id()}"/>
            </xsl:when>
            <xsl:otherwise>
                <fo:block id="{generate-id()}"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="tei:anchor[@type = 'Sachschlagwörter']">
        <xsl:choose>
            <xsl:when test="ancestor::tei:*[local-name() = 'p' or local-name() = 'note' or local-name() = 'table']">
                <fo:inline id="{generate-id()}"/>
            </xsl:when>
            <xsl:otherwise>
                <fo:block id="{generate-id()}"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>



    <!-- Titel aus Gesamtdatei unterdrücken (stattdessen Titel aus Dokumenten selbst nehmen -->
    <xsl:template match="tei:front/tei:head"/>

    <!-- - - - - - - - - - -    GRUßWORTE   - - - - - - - - - - -->
    <xsl:template match="tei:closer">
        <fo:table table-layout="fixed" width="117mm" space-before="10pt" space-after="3pt" border-collapse="separate" border-spacing="5pt 0pt" hyphenate="false">
            <fo:table-column column-width="56mm"/>
            <fo:table-column column-width="5mm"/>
            <fo:table-column column-width="56mm"/>

            <fo:table-body>
                <xsl:choose>
                    <!--Vier Grußworte: Layout =    o x
                                                    x x
                                                    x o
                    -->
                    <xsl:when test="count(tei:seg) = 4">
                        <fo:table-row keep-together.within-page="always">
                            <fo:table-cell text-align="center">
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[1]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>

                        <fo:table-row keep-together.within-page="always">
                            <fo:table-cell text-align="center" padding-top="1em">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[2]"/>
                                </fo:block>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center" padding-top="1em">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[3]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>

                        <fo:table-row keep-together.within-page="always">
                            <fo:table-cell text-align="center" padding-top="1em">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[4]"/>
                                </fo:block>
                            </fo:table-cell>


                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>


                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>
                        </fo:table-row>


                    </xsl:when>



                    <!--Drei Grußworte: Layout =    o x
                                                    x x
                    -->
                    <xsl:when test="count(tei:seg) = 3">
                        <fo:table-row keep-together.within-page="always">
                            <fo:table-cell text-align="center">
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[1]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>

                        <fo:table-row keep-together.within-page="always">
                            <fo:table-cell text-align="center" padding-top="1em">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[2]"/>
                                </fo:block>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center" padding-top="1em">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[3]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </xsl:when>


                    <!--Zwei Grußworte: Layout =  x x -->
                    <xsl:when test="count(tei:seg) = 2">
                        <fo:table-row keep-together.within-page="always">
                            <fo:table-cell text-align="center">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[1]"/>
                                </fo:block>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[2]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </xsl:when>

                    <!-- Ein Grußwort: Layout = o x -->
                    <xsl:when test="count(tei:seg) = 1">
                        <fo:table-row keep-together.within-page="always">
                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell>
                                <fo:block/>
                            </fo:table-cell>

                            <fo:table-cell text-align="center">
                                <fo:block>
                                    <xsl:apply-templates select="tei:seg[1]"/>
                                </fo:block>
                            </fo:table-cell>
                        </fo:table-row>
                    </xsl:when>
                </xsl:choose>
            </fo:table-body>
        </fo:table>
    </xsl:template>


    <!-- - - - - - - - - - -    DRUCKSTEUERUNG  - - - - - - - - - - -->
    <xsl:template match="tei:seg[@type = 'no_trenn']">
        <fo:inline keep-together.within-line="always">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

    <xsl:template match="processing-instruction('seite_umbrechen')">
        <fo:block page-break-after="always"/>
    </xsl:template>

    <xsl:template match="processing-instruction('spalte_umbrechen')">
        <fo:block break-after="column"/>
    </xsl:template>
    
    <xsl:template match="processing-instruction('zeile_umbrechen')">
        <fo:block/>
    </xsl:template>


    <!-- - - - - - - - - -  FUNKTIONEN  - - - - - - - - - - -->
    <xsl:function name="hiko:getDocumentID">
        <xsl:param name="node"/>
        <xsl:variable name="bodyID">
            <xsl:value-of select="$node/ancestor::tei:body/@xml:id"/>
        </xsl:variable>
        <xsl:value-of select="substring-after($bodyID, '_')"/>
    </xsl:function>


    <!-- Den Abstand der Fußnotenziffer zum vorhergehenden Text festlegen um Zeichenüberschneidung zu vermeiden
         Die Breite des Abstandes hängt vom vorausgehenden Zeichen ab und davon ob dieses Zeichen kursiv gestezt ist
         Der Abstand muss erhöht werden:
                            
         wenn die Fußnotenziffer in einer Top-Überschrift steht (da kursiv)
         wenn die Fußnotenziffer hinter kursiviertem Fließtext steht (markierte Sprecher, Fremdwörter, freie Kursivierung)
         bei einzelnen, problematischen Zeichen auch bei nicht kursiviertem Text -->
    <xsl:function name="hiko:getFootnotePadding">
        <xsl:param name="noteNode"/>
        <xsl:variable name="precedingTextnode" select="normalize-space(string($noteNode/preceding::text()[1]))"/>
        <xsl:variable name="precedingTextnodeLength" select="string-length($precedingTextnode)"/>
        <xsl:variable name="precedingTextnodeLastchar" select="substring($precedingTextnode, $precedingTextnodeLength)"/>

        <xsl:choose>
            <xsl:when test="$noteNode/parent::tei:head/parent::tei:div[@type = 'Top']">
                <xsl:choose>
                    <xsl:when test="matches($precedingTextnodeLastchar, '[eklrs)]')">
                        <xsl:value-of select="$fnpadding_sm"/>
                    </xsl:when>
                    <xsl:when test="matches($precedingTextnodeLastchar, '[dGgt0“]')">
                        <xsl:value-of select="$fnpadding_md"/>
                    </xsl:when>
                    <xsl:when test="matches($precedingTextnodeLastchar, 'f')">
                        <xsl:value-of select="$fnpadding_lg"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="'0em'"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:choose>
                    <xsl:when test="$noteNode/preceding::text()[1]/parent::*[(local-name() = 'rs' and @type = 'Sprecher') or local-name() = 'foreign' or (local-name() = 'hi' and @rend = 'italic')]">
                        <xsl:choose>
                            <xsl:when test="matches($precedingTextnodeLastchar, '[eklrs)]')">
                                <xsl:value-of select="$fnpadding_sm"/>
                            </xsl:when>
                            <xsl:when test="matches($precedingTextnodeLastchar, '[dGgt0“]')">
                                <xsl:value-of select="$fnpadding_md"/>
                            </xsl:when>
                            <xsl:when test="matches($precedingTextnodeLastchar, 'f')">
                                <xsl:value-of select="$fnpadding_lg"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="'0em'"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:choose>
                            <xsl:when test="matches($precedingTextnodeLastchar, 'g')">
                                <xsl:value-of select="$fnpadding_sm"/>
                            </xsl:when>
                            <xsl:when test="matches($precedingTextnodeLastchar, 'f')">
                                <xsl:value-of select="$fnpadding_md"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="'0em'"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:function>


    <!-- - - - - - - - - - -    TITELEI - - - - - - - - - - -->
    <xsl:template match="tei:div[@type = 'Titelei_Seite']">
        <fo:block page-break-after="always">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
    
    <xsl:template match="*[@xml:id = 'titl_1_editionstitel']">
        <fo:block text-align="center" font-size="14pt">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
    
    <!--Logos für Titelei müssen in Unterordner "images" im selben Verzeichnis wie die transformierte (Gesamt-)Datei liegen-->
    <xsl:template match="*[@xml:id = 'titl_1_hikologo']">
        <fo:block text-align="center" margin-top="143mm">
            <fo:external-graphic src="images/hiko_logo_sw.png" content-height="34mm" content-width="auto"/>

        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_2_editionstitel']">
        <fo:block text-align="center" font-size="30pt" line-height="110%">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_2_herausgeber']">
        <fo:block text-align="center" font-size="14pt" margin-top="14mm" line-height="110%">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_3_kabinetttitel']">
        <fo:block text-align="center" font-size="30pt" line-height="110%">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_3_kabinettzeit']">
        <fo:block text-align="center" font-size="20pt" margin-top="16mm" line-height="120%">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_3_bandtitel']">
        <fo:block text-align="center" font-size="14pt" margin-top="10mm" line-height="120%">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_3_bearbeiter']">
        <fo:block text-align="center" font-size="14pt" margin-top="11mm" line-height="120%">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_3_degruyterlogo']">
        <fo:block text-align="center" margin-top="77mm">
            <fo:external-graphic src="images/logo_dg-oldenbourg_schriftzug.svg" content-height="8mm" content-width="auto"/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_4_dnbinfo']">
        <fo:block margin-top="25mm">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_4_locinfo']">
        <fo:block margin-top="45mm">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_4_urheberrecht']">
        <fo:block margin-top="12mm">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_4_isbn']">
        <fo:block margin-top="6mm">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_4_druckinfo']">
        <fo:block margin-top="7mm">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="*[@xml:id = 'titl_4_dgwebsite']">
        <fo:block margin-top="6mm">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>

    <xsl:template match="tei:seg[@type = 'Titelei_Untersegment']">
        <xsl:variable name="font-family">
            <xsl:choose>
                <xsl:when test="./@rend = 'italic'"> AGaramondPHK-Italic </xsl:when>
                <xsl:otherwise> AGaramondPHK-Regular </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <fo:block text-align="left" font-size="10pt" font-family="{$font-family}" margin-top="0.25em" line-height="1em">
            <xsl:apply-templates/>
        </fo:block>
    </xsl:template>
</xsl:stylesheet>
