<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:hiko="http://www.historischekommission-muenchen.de" exclude-result-prefixes="xs tei hiko">
    <xsl:output method="xml" version="1.0" encoding="UTF-8"/>

    <xsl:param name="PROJECT_PATH" select="''"/>
    <xsl:variable name="project_path" select="$PROJECT_PATH"/>

    <xsl:variable name="volume">
        <xsl:value-of select="//tei:title[@type = 'Band']/@n"/>
    </xsl:variable>
    <xsl:variable name="prot_path" select="concat($project_path, '/edition-', $volume, '/Protokolle/')"/>

    <xsl:variable name="protocols" select="collection(concat($prot_path,'?select=*p*.xml'))"/>

    <xsl:template match="/">
        <xsl:processing-instruction name="xml-model">href="http://www.tei-c.org/release/xml/tei/custom/schema/relaxng/tei_lite.rng" type="application/xml" schematypens="http://relaxng.org/ns/structure/1.0"</xsl:processing-instruction>
        <xsl:processing-instruction name="xml-model">href="http://www.tei-c.org/release/xml/tei/custom/schema/relaxng/tei_lite.rng" type="application/xml" schematypens="http://purl.oclc.org/dsdl/schematron"</xsl:processing-instruction>

        <xsl:choose>
            <xsl:when test="$volume = 'ehr33'">
                <TEI xmlns="http://www.tei-c.org/ns/1.0" xml:id="ehr33aPTVZ">
                    <teiHeader xmlns="http://www.tei-c.org/ns/1.0">
                        <fileDesc xmlns="http://www.tei-c.org/ns/1.0">
                            <titleStmt xmlns="http://www.tei-c.org/ns/1.0">
                                <title xmlns="http://www.tei-c.org/ns/1.0" type="Reihe" n="ehr3">Das Kabinett Ehard III. 18. Dezember 1950
                                    bis 14. Dezember 1954</title>
                                <title xmlns="http://www.tei-c.org/ns/1.0" type="Band" n="ehr33">Band 3. 8.1.1953-29.12.1953</title>
                                <title xmlns="http://www.tei-c.org/ns/1.0" type="Abschnitt" n="PTVZ">Verzeichnis der Protokolle und der
                                    Tagesordnungspunkte</title>
                                <editor xmlns="http://www.tei-c.org/ns/1.0" xml:id="brn">Oliver Braun</editor>
                            </titleStmt>
                            <publicationStmt xmlns="http://www.tei-c.org/ns/1.0">
                                <p xmlns="http://www.tei-c.org/ns/1.0">Herausgegeben von der Historischen Kommission bei der Bayerischen
                                    Akademie der Wissenschaften durch Andreas Wirsching und von der Generaldirektion der Staatlichen Archive
                                    Bayerns durch Margit Ksoll-Marcon </p>
                            </publicationStmt>
                            <sourceDesc xmlns="http://www.tei-c.org/ns/1.0">
                                <p xmlns="http://www.tei-c.org/ns/1.0">Die Protokolle des Bayerischen Ministerrats, aufbewahrt im
                                    Bayerischen Hauptstaatsarchiv, München (siehe Verzeichnis der ungedruckten Quellen)</p>
                            </sourceDesc>
                        </fileDesc>
                    </teiHeader>
                    <text>
                        <body xml:id="body_ehr33aPTVZ">
                            <head>Verzeichnis der Protokolle und der Tagesordnungspunkte</head>
                            <div type="Verzeichnis">
                                <xsl:apply-templates select="$protocols" mode="inFile"/>
                            </div>
                        </body>
                    </text>
                </TEI>
            </xsl:when>
            <xsl:when test="$volume = 'ehr34'">
                <TEI xmlns="http://www.tei-c.org/ns/1.0" xml:id="ehr34aPTVZ">
                    <teiHeader xmlns="http://www.tei-c.org/ns/1.0">
                        <fileDesc xmlns="http://www.tei-c.org/ns/1.0">
                            <titleStmt xmlns="http://www.tei-c.org/ns/1.0">
                                <title xmlns="http://www.tei-c.org/ns/1.0" type="Reihe" n="ehr3">Das Kabinett Ehard III. 18. Dezember 1950
                                    bis 14. Dezember 1954</title>
                                <title xmlns="http://www.tei-c.org/ns/1.0" type="Band" n="ehr34">Band 4. 5.1.1954-7.12.1954</title>
                                <title xmlns="http://www.tei-c.org/ns/1.0" type="Abschnitt" n="PTVZ">Verzeichnis der Protokolle und der
                                    Tagesordnungspunkte</title>
                                <editor xmlns="http://www.tei-c.org/ns/1.0" xml:id="brn">Oliver Braun</editor>
                            </titleStmt>
                            <publicationStmt xmlns="http://www.tei-c.org/ns/1.0">
                                <p xmlns="http://www.tei-c.org/ns/1.0">Herausgegeben von der Historischen Kommission bei der Bayerischen
                                    Akademie der Wissenschaften durch Andreas Wirsching und von der Generaldirektion der Staatlichen Archive
                                    Bayerns durch Margit Ksoll-Marcon </p>
                            </publicationStmt>
                            <sourceDesc xmlns="http://www.tei-c.org/ns/1.0">
                                <p xmlns="http://www.tei-c.org/ns/1.0">Die Protokolle des Bayerischen Ministerrats, aufbewahrt im
                                    Bayerischen Hauptstaatsarchiv, München (siehe Verzeichnis der ungedruckten Quellen)</p>
                            </sourceDesc>
                        </fileDesc>
                    </teiHeader>
                    <text>
                        <body xml:id="body_ehr34aPTVZ">
                            <head>Verzeichnis der Protokolle und der Tagesordnungspunkte</head>
                            <div type="Verzeichnis">
                                <xsl:apply-templates select="$protocols" mode="inFile"/>
                            </div>
                        </body>
                    </text>
                </TEI>
            </xsl:when>
            <xsl:when test="$volume = 'hoe21'">
                <TEI xmlns="http://www.tei-c.org/ns/1.0" xml:id="hoe21aPTVZ">
                    <teiHeader xmlns="http://www.tei-c.org/ns/1.0">
                        <fileDesc xmlns="http://www.tei-c.org/ns/1.0">
                            <titleStmt>
                                <title type="Reihe" n="hoe2">Das Kabinett Hoegner II. 15.12.1954 bis 8.10.1957.</title>
                                <title type="Band" n="hoe21">Band 1. 15.12.1954-27.12.1955</title>
                                <title xmlns="http://www.tei-c.org/ns/1.0" type="Abschnitt" n="PTVZ">Verzeichnis der Protokolle und der
                                    Tagesordnungspunkte</title>
                                <editor xml:id="brn">Oliver Braun</editor>
                            </titleStmt>
                            <publicationStmt xmlns="http://www.tei-c.org/ns/1.0">
                                <p xmlns="http://www.tei-c.org/ns/1.0">Herausgegeben von der Historischen Kommission bei der Bayerischen
                                    Akademie der Wissenschaften durch Andreas Wirsching und von der Generaldirektion der Staatlichen Archive
                                    Bayerns durch Margit Ksoll-Marcon </p>
                            </publicationStmt>
                            <sourceDesc xmlns="http://www.tei-c.org/ns/1.0">
                                <p xmlns="http://www.tei-c.org/ns/1.0">Die Protokolle des Bayerischen Ministerrats, aufbewahrt im
                                    Bayerischen Hauptstaatsarchiv, München (siehe Verzeichnis der ungedruckten Quellen)</p>
                            </sourceDesc>
                        </fileDesc>
                    </teiHeader>
                    <text>
                        <body xml:id="body_hoe21aPTVZ">
                            <head>Verzeichnis der Protokolle und der Tagesordnungspunkte</head>
                            <div type="Verzeichnis">
                                <xsl:apply-templates select="$protocols" mode="inFile"/>
                            </div>
                        </body>
                    </text>
                </TEI>
            </xsl:when>
        </xsl:choose>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Dokumentenkopf']" mode="inFile">
        <xsl:variable name="protID">
            <xsl:value-of select="ancestor::tei:TEI/@xml:id"/>
        </xsl:variable>
        <div xmlns="http://www.tei-c.org/ns/1.0" type="Protokollzusammenfassung" corresp="{$protID}">
            <head xmlns="http://www.tei-c.org/ns/1.0">
                <xsl:text> </xsl:text>
                <xsl:apply-templates select="./tei:head/tei:num"/>
                <xsl:text> </xsl:text>
                <xsl:apply-templates select="./tei:head/tei:date"/>
                <xsl:text> </xsl:text>
                <xsl:apply-templates select="./tei:head/tei:seg[@type = 'Protokolltitel']"/>
                <xsl:text> </xsl:text>
            </head>

            <p xmlns="http://www.tei-c.org/ns/1.0">
                <xsl:apply-templates select="//tei:rs[@type = 'Top_Link']"/>
            </p>

        </div>
    </xsl:template>

    <xsl:template match="tei:num">
        <num xmlns="http://www.tei-c.org/ns/1.0">
            <xsl:text>Nr. </xsl:text>
            <xsl:apply-templates/>
        </num>
    </xsl:template>

    <xsl:template match="tei:date">
        <xsl:variable name="datewhen">
            <xsl:value-of select="@when"/>
        </xsl:variable>
        <xsl:variable name="printDate">
            <xsl:value-of select="hiko:whenToDate($datewhen)"/>
        </xsl:variable>

        <date xmlns="http://www.tei-c.org/ns/1.0" when="{$datewhen}">
            <xsl:value-of select="$printDate"/>
        </date>
    </xsl:template>

    <xsl:template match="tei:time"/>

    <xsl:template match="tei:seg[@type = 'Protokolltitel']">
        <title xmlns="http://www.tei-c.org/ns/1.0">
            <xsl:apply-templates/>
        </title>
    </xsl:template>

    <xsl:template match="tei:div[@type = 'Tagesordnung']">
        <p xmlns="http://www.tei-c.org/ns/1.0">
            <xsl:apply-templates/>
        </p>
    </xsl:template>

    <xsl:template match="tei:rs[@type = 'Top_Link']">
        <xsl:variable name="shortendTopID">
            <xsl:value-of select="substring(@key, 2)"/>
        </xsl:variable>
        <xsl:variable name="xmlReference">
            <xsl:value-of select="hiko:constructXmlReference(@key)"/>
        </xsl:variable>

        <rs xmlns="http://www.tei-c.org/ns/1.0" type="Top_Link" key="{$shortendTopID}" ref="{$xmlReference}">
            <xsl:apply-templates/>
        </rs>
        <xsl:text> </xsl:text>
    </xsl:template>

    <xsl:template match="tei:add">
        <add xmlns="http://www.tei-c.org/ns/1.0">
            <xsl:apply-templates/>
        </add>
    </xsl:template>


    <xsl:template match="tei:note" mode="inFile"/>
    <xsl:template match="tei:note"/>
    <xsl:template match="tei:teiHeader" mode="inFile"/>
    <xsl:template match="tei:div[@type = 'Protokoll']" mode="inFile"/>
    <!--xsl:template match="tei:div[@type = 'Freiblock']" mode="inFile"/>
    <xsl:template match="*/text()" mode="inFile"/-->

    <!-- Nicht erwünschte versteckte Attribute nicht mitkopieren-->
    <xsl:template match="@org"/>
    <xsl:template match="@default"/>
    <xsl:template match="@part"/>
    <xsl:template match="@sample"/>
    <xsl:template match="@instant"/>
    <xsl:template match="@anchored"/>

    <xsl:function name="hiko:whenToDate">
        <xsl:param name="when"/>
        <xsl:variable name="day">
            <xsl:variable name="rawday" select="substring($when, 9)"/>
            <!-- Ggfs. Führende Null aus Monatszahl entfernen -->
            <xsl:choose>
                <xsl:when test="starts-with($rawday, '0')">
                    <xsl:value-of select="substring($rawday, 2)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$rawday"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="month">
            <xsl:variable name="rawmonth" select="substring($when, 6, 2)"/>
            <!-- Ggfs. Führende Null aus Monatszahl entfernen -->
            <xsl:choose>
                <xsl:when test="starts-with($rawmonth, '0')">
                    <xsl:value-of select="substring($rawmonth, 2)"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="$rawmonth"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="year">
            <xsl:value-of select="substring($when, 1, 4)"/>
        </xsl:variable>
        <xsl:value-of select="concat($day, '.', $month, '.', $year)"/>
    </xsl:function>



    <xsl:function name="hiko:constructXmlReference">
        <xsl:param name="topID"/>
        <xsl:variable name="documentID">
            <xsl:value-of select="substring($topID, 2, 9)"/>
        </xsl:variable>

        <xsl:value-of select="concat($documentID, '.xml', $topID)"/>

    </xsl:function>



</xsl:stylesheet>
