<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:hiko="http://www.historischekommission-muenchen.de" xmlns:my="http://zeromat.org" version="2.0">

    <xsl:import href="Druck/minrprot_druck_pdf.xsl"/>

    <!--Dokumententyp ermitteln anhand des 6. Zeichens in der DokumentenID
        a = Abschnitt
        p = Protokoll 
    -->
    <xsl:variable name="docType">
        <xsl:value-of select="substring($currentDocID, 6, 1)"/>
    </xsl:variable>

    <xsl:template match="/">
        <fo:root font-size="{$ftsz_Fließtext}" font-family="{$ftSf}" line-height="115%" xml:lang="de" hyphenate="true" line-height-shift-adjustment="disregard-shifts" hyphenation-push-character-count="4" hyphenation-remain-character-count="4">
            <fo:layout-master-set>
                <fo:simple-page-master master-name="PageMaster.Inhalt-rechts"  margin-top="12mm" margin-bottom="30mm" margin-left="17mm" margin-right="21mm" page-height="235mm" page-width="155mm">
                    <fo:region-body space-before="9mm"/>
                    <fo:region-before region-name="Inhalt-rechts-davor" extent="15mm" display-align="before" border-after-style="solid" padding="0" border="0"/>
                </fo:simple-page-master>

                <fo:simple-page-master master-name="PageMaster.Inhalt-links" margin-top="12mm" margin-bottom="30mm" margin-left="21mm" margin-right="17mm" page-height="235mm" page-width="155mm">
                    <fo:region-body space-before="9mm"/>
                    <fo:region-before region-name="Inhalt-links-davor" extent="15mm" display-align="before" border-after-style="solid" padding="0" border="0"/>
                </fo:simple-page-master>

                <fo:simple-page-master master-name="PageMaster.Inhalt-rechts-start" margin-top="12mm" margin-bottom="30mm" margin-left="17mm" margin-right="21mm" page-height="235mm" page-width="155mm">           
                  <fo:region-body space-before="9mm"/>
                    <fo:region-before region-name="Inhalt-rechts-davor-start" extent="15mm" display-align="before" border-after-style="solid" padding="0" border="0"/>
                </fo:simple-page-master>

                <fo:simple-page-master master-name="PageMaster.Inhalt-links-start" margin-top="12mm" margin-bottom="30mm" margin-left="21mm" margin-right="17mm" page-height="235mm" page-width="155mm">
                    <fo:region-body space-before="9mm"/>
                    <fo:region-before region-name="Inhalt-links-davor-start" extent="15mm" display-align="before" border-after-style="solid" padding="0" border="0"/>
                </fo:simple-page-master>

                <fo:simple-page-master master-name="PageMaster.Teil-Titelseite" margin-top="12mm" margin-bottom="30mm" margin-left="17mm" margin-right="21mm" page-height="235mm" page-width="155mm">
                    <fo:region-body region-name="Teil-Titelseite-Hauptbereich" margin="0mm 0mm 0mm 0mm"/>
                </fo:simple-page-master>

                <fo:page-sequence-master master-name="Inhalt-Seiten" >
                    <fo:repeatable-page-master-alternatives>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Inhalt-links-start" page-position="first" odd-or-even="even"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Inhalt-rechts-start" page-position="first" odd-or-even="odd"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Inhalt-links" page-position="rest" odd-or-even="even"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Inhalt-rechts" page-position="rest" odd-or-even="odd"/>
                        <!--fo:conditional-page-master-reference master-reference="PageMaster.Inhalt-links" page-position="last" odd-or-even="even"/>
                        <fo:conditional-page-master-reference master-reference="PageMaster.Inhalt-rechts" page-position="last" odd-or-even="odd"/-->
                    </fo:repeatable-page-master-alternatives>
                </fo:page-sequence-master>
            </fo:layout-master-set>

            <fo:page-sequence master-reference="Inhalt-Seiten" force-page-count="odd">
                <fo:static-content flow-name="xsl-footnote-separator">
                    <fo:block text-align="justify" padding-top="5mm">
                    </fo:block>
                    <!--border="1pt dotted black"-->
                </fo:static-content>


                <!--Kopfbereich erste Seite rechts - nur schwarzer Querstrich-->
                <fo:static-content flow-name="Inhalt-rechts-davor-start">
                    <fo:block text-align="end" font-size="{$ftsz_Kopfzeile}" border-after-style="solid" border-after-width="0.5pt" border-after-color="black"> </fo:block>
                </fo:static-content>

                <!--Kopfbereich erste Seite links - nur schwarzer Querstrich-->
                <fo:static-content flow-name="Inhalt-links-davor-start">
                    <fo:block text-align="end" font-size="{$ftsz_Kopfzeile}" border-after-style="solid" border-after-width="0.5pt" border-after-color="black"> </fo:block>
                </fo:static-content>


                <xsl:choose>

                    <!--Kopfzeile Editionsabschnitt-->
                    <xsl:when test="$docType = 'a'">
                        
                        <xsl:variable name="head" select="//tei:body/tei:head/text()"/>
                        
                        <!--Kopfbereich Folgeseiten rechts - scharzer Querstrich, Abschnittstitel links, Seitenzahl rechts-->
                        <fo:static-content flow-name="Inhalt-rechts-davor">
                            <fo:table table-layout="fixed" width="117mm" space-before="0pt" space-after="0pt" border-bottom="0.5pt solid black" font-size="{$ftsz_Kopfzeile}">
                                <fo:table-column column-width="87mm"/>
                                <fo:table-column column-width="10mm"/>
                                <fo:table-column column-width="20mm"/>
                                <fo:table-body>
                                    <fo:table-row>
                                        <fo:table-cell text-align="start">
                                            <fo:block>
                                                <xsl:value-of select="$head"/>
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell text-align="center">
                                            <fo:block/>
                                        </fo:table-cell>
                                        <fo:table-cell text-align="end">
                                            <fo:block font-size="{$ftsz_Seitenzahl}">
                                                <fo:page-number/>
                                            </fo:block>
                                        </fo:table-cell>
                                    </fo:table-row>
                                </fo:table-body>
                            </fo:table>
                        </fo:static-content>

                        <!--Kopfbereich Folgeseiten links - scharzer Querstrich, Seitenzahl links, Abschnittstitel rechts-->
                        <fo:static-content flow-name="Inhalt-links-davor">
                            <fo:table table-layout="fixed" width="117mm" space-before="0pt" space-after="0pt" border-bottom="0.5pt solid black" font-size="{$ftsz_Kopfzeile}">
                                <fo:table-column column-width="20mm"/>
                                <fo:table-column column-width="10mm"/>
                                <fo:table-column column-width="87mm"/>
                                <fo:table-body>
                                    <fo:table-row>
                                        <fo:table-cell text-align="start">
                                            <fo:block font-size="{$ftsz_Seitenzahl}">
                                                <fo:page-number/>
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell text-align="center">
                                            <fo:block/>
                                        </fo:table-cell>
                                        <fo:table-cell text-align="end">
                                            <fo:block>
                                                <xsl:value-of select="$head"/>
                                            </fo:block>
                                        </fo:table-cell>
                                    </fo:table-row>
                                </fo:table-body>
                            </fo:table>
                        </fo:static-content>

                        <fo:flow flow-name="xsl-region-body">
                            <fo:block id="{generate-id()}">
                                <xsl:apply-templates select=".//tei:body"/>
                            </fo:block>
                        </fo:flow>
                    </xsl:when>

                    <!-- Kopfzeile Protokolle-->
                    <xsl:when test="$docType = 'p'">
                        <!--Kopfbereich Folgeseiten rechts - schwarzer Querstrich, links Protokollnummer, mitte Datum, rechts Seitenzahl-->
                        <fo:static-content flow-name="Inhalt-rechts-davor">
                            <fo:table table-layout="fixed" width="117mm" space-before="0pt" space-after="0pt" border-bottom="0.5pt solid black" font-size="{$ftsz_Kopfzeile}">
                                <fo:table-column column-width="20mm"/>
                                <fo:table-column column-width="77mm"/>
                                <fo:table-column column-width="20mm"/>
                                <fo:table-body>
                                    <fo:table-row>
                                        <fo:table-cell text-align="start">
                                            <fo:block>
                                                <fo:retrieve-marker retrieve-class-name="protokollnummer" retrieve-boundary="page-sequence" retrieve-position="first-including-carryover"/>
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell text-align="center">
                                            <fo:block>
                                                <fo:retrieve-marker retrieve-class-name="protokolldatum" retrieve-boundary="page-sequence" retrieve-position="first-including-carryover"/>
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell text-align="end">
                                            <fo:block font-size="{$ftsz_Seitenzahl}">
                                                <fo:page-number/>
                                            </fo:block>
                                        </fo:table-cell>
                                    </fo:table-row>
                                </fo:table-body>
                            </fo:table>
                        </fo:static-content>

                        <!--Kopfbereich Folgeseiten rechts - schwarzer Querstrich, links Seitenzahl, mitte Datum, rechts Protokollnummer-->
                        <fo:static-content flow-name="Inhalt-links-davor">
                            <fo:table table-layout="fixed" width="117mm" space-before="0pt" space-after="0pt" border-bottom="0.5pt solid black" font-size="{$ftsz_Kopfzeile}">
                                <fo:table-column column-width="20mm"/>
                                <fo:table-column column-width="77mm"/>
                                <fo:table-column column-width="20mm"/>
                                <fo:table-body>
                                    <fo:table-row>
                                        <fo:table-cell text-align="start">
                                            <fo:block font-size="{$ftsz_Seitenzahl}">
                                                <fo:page-number/>
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell text-align="center">
                                            <fo:block>
                                                <fo:retrieve-marker retrieve-class-name="protokolldatum" retrieve-boundary="page-sequence" retrieve-position="first-including-carryover"/>
                                            </fo:block>
                                        </fo:table-cell>
                                        <fo:table-cell text-align="end">
                                            <fo:block>
                                                <fo:retrieve-marker retrieve-class-name="protokollnummer" retrieve-boundary="page-sequence" retrieve-position="first-including-carryover"/>
                                            </fo:block>
                                        </fo:table-cell>
                                    </fo:table-row>
                                </fo:table-body>
                            </fo:table>
                        </fo:static-content>

                        <fo:flow flow-name="xsl-region-body">
                            <fo:block-container keep-together="always">
                                <fo:block text-align="center" id="{generate-id()}">
                                    <fo:marker marker-class-name="protokollNummer">
                                        <xsl:value-of select="tei:div[@type = 'Protokollnummer']/tei:head/tei:num"/>
                                    </fo:marker>
                                </fo:block>
                            </fo:block-container>                            
                            <xsl:apply-templates select="//tei:body"/>
                        </fo:flow>
                    </xsl:when>
                </xsl:choose>
            </fo:page-sequence>
        </fo:root>
    </xsl:template>
    
    <!-- - - - - - - - - - -    BIOGRAMMPLATZHALTER - - - - - - - - - - -->
    <xsl:template match="tei:ref[@type = 'Biogramm_Platzhalter']">
        <xsl:variable name="placeholderID">
            <xsl:value-of select="./@target"/>
        </xsl:variable>
        <xsl:variable name="placeholderValue">
            <xsl:value-of select="$per//tei:person[@xml:id = $placeholderID]/tei:note[@type = 'Biogramm']"/>
        </xsl:variable>
        
        <!--Falls Biogramm noch nicht ausgefüllt ist bleibt der Biogrammplatzhalter stehen-->
        <fo:inline id="{generate-id()}">
            <xsl:choose>
                <xsl:when test="$placeholderValue != ''">
                    <xsl:apply-templates select="$per//tei:person[@xml:id = $placeholderID]/tei:note[@type = 'Biogramm']"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates/>
                </xsl:otherwise>
            </xsl:choose>
        </fo:inline>
    </xsl:template>
    
    <xsl:template match="tei:note[@type = 'Biogramm']">
        <xsl:apply-templates/>
    </xsl:template>
    
    <xsl:template match="tei:note[@type = 'Biogramm']/tei:name[@type = 'Hervorhebung']">
        <fo:inline font-family="{$ftSfObl}">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>

</xsl:stylesheet>
