<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:tei="http://www.tei-c.org/ns/1.0" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:hiko="http://www.historischekommission-muenchen.de" xmlns:my="http://zeromat.org" version="2.0">

    <xsl:import href="../../tei_oxydition_minrprot/transformations/minrprot_ansicht_pdf.xsl"/>

    <!-- - - - - - - - - - -    SCHRIFTGRÖẞEN   - - - - - - - - - - -->
    <xsl:variable name="ftsz_Fließtext" select="'12pt'"/>
    <xsl:variable name="ftsz_Protokollkopf" select="'15pt'"/>
    <xsl:variable name="ftsz_Überschrift_Abschnitt" select="'15pt'"/>

    <xsl:variable name="ftsz_Kopfzeile" select="'10pt'"/>
    <xsl:variable name="ftsz_Seitenzahl" select="'10pt'"/>

    <xsl:variable name="ftsz_Fußnoten" select="'10pt'"/>
    <xsl:variable name="ftsz_Fußnziffer_Text" select="'10pt'"/>
    <xsl:variable name="ftsz_Fußnziffer_Apparat" select="'6pt'"/>

    <xsl:variable name="ftsz_Erläuterungstext" select="'10pt'"/>
    <xsl:variable name="ftsz_PTVZTO" select="'10pt'"/>

    <!-- - - - - - - - - - -    BASIS   - - - - - - - - - - -->
    <xsl:template match="/">
        <fo:root font-size="{$ftsz_Fließtext}" font-family="{$ftSf}" line-height="150%" xml:lang="de" hyphenate="true" line-height-shift-adjustment="disregard-shifts" hyphenation-push-character-count="4" hyphenation-remain-character-count="4">

            <!--Seite einrichten-->
            <fo:layout-master-set>
                <fo:simple-page-master master-name="standart-seite" page-height="297mm" page-width="210mm" margin-left="15mm" margin-right="25mm" margin-top="20mm" margin-bottom="20mm">
                    <fo:region-body margin-top=".5in" margin-bottom="0.7in"/>
                    <fo:region-before extent=".5in" region-name="xsl-region-before"/>
                </fo:simple-page-master>
            </fo:layout-master-set>

            <fo:page-sequence master-reference="standart-seite">

                <!--Kopfzeile-->
                <fo:static-content flow-name="xsl-region-before">
                    <fo:table table-layout="fixed" width="170mm" space-before="0pt" space-after="0pt" border-bottom="1px solid black" color="#336699">
                        <fo:table-column column-width="20mm" text-align="left"/>
                        <fo:table-column column-width="130mm" text-align="center"/>
                        <fo:table-column column-width="20mm" text-align="end"/>
                        <fo:table-body>
                            <fo:table-row>
                                <fo:table-cell>
                                    <fo:block>
                                        <xsl:text>Nr. </xsl:text>
                                        <xsl:value-of select="//tei:title[@type = 'Protokoll']"/>
                                    </fo:block>
                                </fo:table-cell>
                                <fo:table-cell text-align="center">
                                    <fo:block>
                                        <xsl:value-of select="my:replMonth(format-date(//tei:div[@type = 'Dokumentenkopf']//tei:head[1]//tei:date[1]/@when, '[D1]. [MNn] [Y0001]'))"/>
                                    </fo:block>
                                </fo:table-cell>
                                <fo:table-cell>
                                    <fo:block font-size="{$ftsz_Seitenzahl}" text-align="right">
                                        <fo:page-number/>
                                    </fo:block>
                                </fo:table-cell>
                            </fo:table-row>
                        </fo:table-body>
                    </fo:table>
                </fo:static-content>

                <!--Hauptteil-->
                <fo:flow flow-name="xsl-region-body">
                    <xsl:apply-templates select="//tei:text"/>
                </fo:flow>

            </fo:page-sequence>
        </fo:root>
    </xsl:template>




    <!-- - - - - - - - - - -    FU?NOTEN    - - - - - - - - - - -->
    <xsl:template match="tei:note">
        <xsl:variable name="footnoteNumber">
            <xsl:choose>
                <xsl:when test="@n">
                    <xsl:value-of select="@n"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="count(preceding::tei:note) + 1"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <fo:footnote>
            <fo:inline font-size="{$ftsz_Fußnziffer_Text}" baseline-shift="super" font-family="{$ftSf}">
                <xsl:value-of select="$footnoteNumber"/>
            </fo:inline>
            <fo:footnote-body font-size="{$ftsz_Fußnoten}" font-family="{$ftSf}" color="black" text-indent="0" line-height="130%" text-align="justify">
                <fo:list-block provisional-distance-between-starts="4mm">
                    <fo:list-item>
                        <fo:list-item-label end-indent="label-end()">
                            <fo:block font-size="{$ftsz_Fußnziffer_Apparat}" baseline-shift="super">
                                <xsl:value-of select="$footnoteNumber"/>
                            </fo:block>
                        </fo:list-item-label>
                        <fo:list-item-body start-indent="body-start()">
                            <fo:block>
                                <xsl:apply-templates/>
                            </fo:block>
                        </fo:list-item-body>
                    </fo:list-item>
                </fo:list-block>
            </fo:footnote-body>
        </fo:footnote>
    </xsl:template>

    <!--Zweite Version für Datumszeile-->
    <xsl:template match="tei:note" mode="ohnezeit">
        <xsl:variable name="footnoteNumber">
            <xsl:choose>
                <xsl:when test="@n">
                    <xsl:value-of select="@n"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="count(preceding::tei:note) + 1"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>

        <fo:footnote>
            <fo:inline font-size="{$ftsz_Fußnziffer_Text}" baseline-shift="super">
                <xsl:value-of select="$footnoteNumber"/>
            </fo:inline>
            <fo:footnote-body font-size="{$ftsz_Fußnoten}" font-family="{$ftSf}" color="black" text-indent="0" line-height="130%" text-align="justify">
                <fo:list-block provisional-distance-between-starts="4mm">
                    <fo:list-item>
                        <fo:list-item-label end-indent="label-end()">
                            <fo:block font-size="{$ftsz_Fußnziffer_Apparat}" baseline-shift="super">
                                <xsl:value-of select="$footnoteNumber"/>
                            </fo:block>
                        </fo:list-item-label>
                        <fo:list-item-body start-indent="body-start()">
                            <fo:block>
                                <xsl:apply-templates/>
                            </fo:block>
                        </fo:list-item-body>
                    </fo:list-item>
                </fo:list-block>
            </fo:footnote-body>
        </fo:footnote>
    </xsl:template>

    <!-- - - - - - - - - - -    BIOGRAMMPLATZHALTER - - - - - - - - - - -->
    <xsl:template match="tei:ref[@type = 'Biogramm_Platzhalter']">
        <xsl:variable name="placeholderID">
            <xsl:value-of select="./@target"/>
        </xsl:variable>
        <xsl:variable name="placeholderValue">
            <xsl:value-of select="$per//tei:person[@xml:id = $placeholderID]/tei:note[@type = 'Biogramm']"/>
        </xsl:variable>

        <!--Falls Biogramm noch nicht ausgefüllt ist bleibt der Biogrammplatzhalter stehen-->
        <fo:inline id="{generate-id()}">
            <xsl:choose>
                <xsl:when test="$placeholderValue != ''">
                    <xsl:apply-templates select="$per//tei:person[@xml:id = $placeholderID]/tei:note[@type = 'Biogramm']"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates/>
                </xsl:otherwise>
            </xsl:choose>
        </fo:inline>
    </xsl:template>

    <xsl:template match="tei:note[@type = 'Biogramm']">
        <xsl:apply-templates/>
    </xsl:template>

    <xsl:template match="tei:note[@type = 'Biogramm']/tei:name[@type = 'Hervorhebung']">
        <fo:inline font-family="{$ftSfObl}">
            <xsl:apply-templates/>
        </fo:inline>
    </xsl:template>













</xsl:stylesheet>
